import platform

from ctypes import *
from importlib_resources import files

if platform.uname()[0] == "Windows":
    lib_name = "libilivalidator.dll"
elif platform.uname()[0] == "Linux":
    lib_name = "libilivalidator.so"
else:
    lib_name = "libilivalidator.dylib"

def quicktext():
    print('Hello, welcome to QuickFoo package.')

class Ilivalidator:                     
    #global isolatethread
    #global dll 

    #isolatethread = None 
    #dll = None

    def validate(data_file_name):
        lib_path = files('ilivalidator.lib_ext').joinpath(lib_name)
        # str() seems to be necessary on windows: https://github.com/TimDettmers/bitsandbytes/issues/30
        dll = CDLL(str(lib_path))
        isolate = c_void_p()
        isolatethread = c_void_p()
        dll.graal_create_isolate(None, byref(isolate), byref(isolatethread))
        dll.ilivalidator.restype = bool

        result = dll.ilivalidator(isolatethread, c_char_p(bytes(data_file_name, "utf8")))
        return result

Ilivalidator.validate = staticmethod(Ilivalidator.validate)



import os
from setuptools import setup, find_packages

# buildNumber = 'LOCALBUILD'
# if os.environ.get('GITHUB_RUN_NUMBER'): 
#     buildNumber = os.environ.get('GITHUB_RUN_NUMBER')

with open('README.md') as readme_file:
    readme = readme_file.read()

setup(
    author="Stefan Ziegler",
    author_email='edi.gonzales@gmail.com',
    python_requires='>=3.8',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        'Operating System :: POSIX :: Linux',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: MacOS',
    ],
    description="Python package for ilivalidator.",
    install_requires=['importlib-resources'] ,
    license="MIT license",
    long_description=readme,
    long_description_content_type="text/markdown",
    include_package_data=True,
    keywords='ilivalidator,interlis',
    name='ilivalidator',
    packages=find_packages(include=['ilivalidator', 'ilivalidator.*']),
    package_data={'ilivalidator.lib_ext':['*.h', '*.lib', '*.dll', '*.so', '*.dylib']},
    #test_suite='tests',
    #tests_require=test_requirements,
    url='https://github.com/pylitools/ilivalidator',
    version='0.0.1',
)
